geowatch.tasks.fusion.methods.object\_head module
=================================================

.. automodule:: geowatch.tasks.fusion.methods.object_head
   :members:
   :undoc-members:
   :show-inheritance:
